resultSet.SimpleResultSetItem

|  | ## Cheshire3 Object Model: Class SimpleResultSetItem

Module resultSet :: Class SimpleResultSetItem

## Class SimpleResultSetItem
source code

Object Tree:

                   object --+
                            |
    baseObjects.ResultSetItem --+
                                |
                               SimpleResultSetItem

Instance Methods

__init__(self, session, docid=0, recStore="", occs=0, database="", diagnostic=None, weight=0.5, resultSet=None, numeric=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
fetch_record(self, session)
__eq__(self, other)
__str__(self) str(x)
__repr__(self) repr(x)
__cmp__(self, other)
__hash__(self) hash(x)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`

Class Variables

docid |
numericId |
recordStore |
database |
occurences |
weight |
scaledWeight |
diagnostic |
proxInfo |
Inherited from `object`: `__class__`

Method Details

### __init__(self, session, docid=0, recStore="", occs=0, database="", diagnostic=None, weight=0.5, resultSet=None, numeric=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### fetch_record(self, session) | source code

### __eq__(self, other) (Equality operator) | source code

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### __cmp__(self, other) (Comparison operator) | source code

### __hash__(self) (Hashing function) | source code
hash(x) Overrides: object.__hash__ (inherited documentation)

Class Variable Details

    ### docid Value:
        0

    ### numericId Value:
        None

    ### recordStore Value:
        ""

    ### database Value:
        ''

    ### occurences Value:
        0

    ### weight Value:
        0.5

    ### scaledWeight Value:
        0.5

    ### diagnostic Value:
        None

    ### proxInfo Value:
        []